@@ -6,7 +6,7 @@ Mojo::IOLoop::ReadWriteFork - Fork a process and read/write from it
 
 =head1 VERSION
 
-0.13
+0.14
 
 =head1 DESCRIPTION
 
@@ -68,7 +68,7 @@ sub ESC {
   $_;
 }
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 our @SAFE_SIG = grep {
   not /^(
@@ -374,16 +374,20 @@ sub _sigchld {
 
 sub _watch_pid {
   my ($self, $pid) = @_;
+  my $chld = $SIG{CHLD} || '';
   my $reactor = $self->ioloop->reactor;
 
-  if ($reactor->isa('Mojo::Reactor::EV')) {
-    Scalar::Util::weaken($self);
-    $self->{ev_child} = EV::child($pid, 0, sub { _sigchld($self, $pid, $_[0]->rstatus); });
-  }
-  else {
+  # The $chld test is for code, such as Minion::Command::minion::worker
+  # where SIGCHLD is set up to DEFAULT for manual waitpid() checks.
+  # See https://github.com/kraih/minion/issues/15 for details.
+  if ($chld eq 'DEFAULT' or !$reactor->isa('Mojo::Reactor::EV')) {
     $reactor->{fork_watcher} ||= $reactor->recurring(WAIT_PID_INTERVAL, \&_watch_forks);
     Scalar::Util::weaken($reactor->{forks}{$pid} = $self);
   }
+  else {
+    Scalar::Util::weaken($self);
+    $self->{ev_child} = EV::child($pid, 0, sub { _sigchld($self, $pid, $_[0]->rstatus); });
+  }
 }
 
 sub _watch_forks {
